@@ -7,7 +7,6 @@ import inspect
 import os
 import pkg_resources
 import re
-import six
 import types
 from abc import abstractmethod
 from io import BytesIO
@@ -16,7 +15,8 @@ from botocore.config import Config
 from botocore.handlers import BUILTIN_HANDLERS
 from botocore.awsrequest import AWSResponse
 from distutils.version import LooseVersion
-from six.moves.urllib.parse import urlparse
+from http.client import responses as http_responses
+from urllib.parse import urlparse
 from werkzeug.wrappers import Request
 
 from moto import settings
@@ -33,7 +33,7 @@ ACCOUNT_ID = os.environ.get("MOTO_ACCOUNT_ID", "123456789012")
 RESPONSES_VERSION = pkg_resources.get_distribution("responses").version
 
 
-class BaseMockAWS(object):
+class BaseMockAWS:
     nested_count = 0
     mocks_active = False
 
@@ -213,12 +213,12 @@ class CallbackResponse(responses.CallbackResponse):
             url = urlparse(request.url)
             if request.body is None:
                 body = None
-            elif isinstance(request.body, six.text_type):
-                body = six.BytesIO(six.b(request.body))
+            elif isinstance(request.body, str):
+                body = BytesIO(request.body.encode("UTF-8"))
             elif hasattr(request.body, "read"):
-                body = six.BytesIO(request.body.read())
+                body = BytesIO(request.body.read())
             else:
-                body = six.BytesIO(request.body)
+                body = BytesIO(request.body)
             req = Request.from_values(
                 path="?".join([url.path, url.query]),
                 input_stream=body,
@@ -228,7 +228,7 @@ class CallbackResponse(responses.CallbackResponse):
                 base_url="{scheme}://{netloc}".format(
                     scheme=url.scheme, netloc=url.netloc
                 ),
-                headers=[(k, v) for k, v in six.iteritems(request.headers)],
+                headers=[(k, v) for k, v in request.headers.items()],
             )
             request = req
         headers = self.get_headers()
@@ -243,7 +243,7 @@ class CallbackResponse(responses.CallbackResponse):
 
         return responses.HTTPResponse(
             status=status,
-            reason=six.moves.http_client.responses.get(status),
+            reason=http_responses.get(status),
             body=body,
             headers=headers,
             preload_content=False,
@@ -261,7 +261,7 @@ class CallbackResponse(responses.CallbackResponse):
         if responses._is_string(url):
             if responses._has_unicode(url):
                 url = responses._clean_unicode(url)
-                if not isinstance(other, six.text_type):
+                if not isinstance(other, str):
                     other = other.encode("ascii").decode("utf8")
             return self._url_matches_strict(url, other)
         elif isinstance(url, responses.Pattern) and url.match(other):
@@ -319,7 +319,7 @@ BOTOCORE_HTTP_METHODS = ["GET", "DELETE", "HEAD", "OPTIONS", "PATCH", "POST", "P
 
 class MockRawResponse(BytesIO):
     def __init__(self, input):
-        if isinstance(input, six.text_type):
+        if isinstance(input, str):
             input = input.encode("utf-8")
         super(MockRawResponse, self).__init__(input)
 
@@ -330,7 +330,7 @@ class MockRawResponse(BytesIO):
             contents = self.read()
 
 
-class BotocoreStubber(object):
+class BotocoreStubber:
     def __init__(self):
         self.enabled = False
         self.methods = defaultdict(list)
@@ -363,7 +363,7 @@ class BotocoreStubber(object):
 
         if response_callback is not None:
             for header, value in request.headers.items():
-                if isinstance(value, six.binary_type):
+                if isinstance(value, bytes):
                     request.headers[header] = value.decode("utf-8")
             status, headers, body = response_callback(
                 request, request.url, request.headers
@@ -479,43 +479,10 @@ class ServerModeMockAWS(BaseMockAWS):
                 kwargs["endpoint_url"] = "http://localhost:5000"
             return real_boto3_resource(*args, **kwargs)
 
-        def fake_httplib_send_output(self, message_body=None, *args, **kwargs):
-            def _convert_to_bytes(mixed_buffer):
-                bytes_buffer = []
-                for chunk in mixed_buffer:
-                    if isinstance(chunk, six.text_type):
-                        bytes_buffer.append(chunk.encode("utf-8"))
-                    else:
-                        bytes_buffer.append(chunk)
-                msg = b"\r\n".join(bytes_buffer)
-                return msg
-
-            self._buffer.extend((b"", b""))
-            msg = _convert_to_bytes(self._buffer)
-            del self._buffer[:]
-            if isinstance(message_body, bytes):
-                msg += message_body
-                message_body = None
-            self.send(msg)
-            # if self._expect_header_set:
-            #     read, write, exc = select.select([self.sock], [], [self.sock], 1)
-            #     if read:
-            #         self._handle_expect_response(message_body)
-            #         return
-            if message_body is not None:
-                self.send(message_body)
-
         self._client_patcher = patch("boto3.client", fake_boto3_client)
         self._resource_patcher = patch("boto3.resource", fake_boto3_resource)
-        if six.PY2:
-            self._httplib_patcher = patch(
-                "httplib.HTTPConnection._send_output", fake_httplib_send_output
-            )
-
         self._client_patcher.start()
         self._resource_patcher.start()
-        if six.PY2:
-            self._httplib_patcher.start()
 
     def _get_region(self, *args, **kwargs):
         if "region_name" in kwargs:
@@ -529,8 +496,6 @@ class ServerModeMockAWS(BaseMockAWS):
         if self._client_patcher:
             self._client_patcher.stop()
             self._resource_patcher.stop()
-            if six.PY2:
-                self._httplib_patcher.stop()
 
 
 class Model(type):
@@ -572,8 +537,7 @@ class InstanceTrackerMeta(type):
         return cls
 
 
-@six.add_metaclass(InstanceTrackerMeta)
-class BaseModel(object):
+class BaseModel(metaclass=InstanceTrackerMeta):
     def __new__(cls, *args, **kwargs):
         instance = super(BaseModel, cls).__new__(cls)
         cls.instances.append(instance)
@@ -598,6 +562,7 @@ class CloudFormationModel(BaseModel):
         # See for example https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dynamodb-table.html
         return "AWS::SERVICE::RESOURCE"
 
+    @classmethod
     @abstractmethod
     def create_from_cloudformation_json(
         cls, resource_name, cloudformation_json, region_name
@@ -608,6 +573,7 @@ class CloudFormationModel(BaseModel):
         # and return an instance of the resource class
         pass
 
+    @classmethod
     @abstractmethod
     def update_from_cloudformation_json(
         cls, original_resource, new_resource_name, cloudformation_json, region_name
@@ -619,6 +585,7 @@ class CloudFormationModel(BaseModel):
         # the change in parameters and no-op when nothing has changed.
         pass
 
+    @classmethod
     @abstractmethod
     def delete_from_cloudformation_json(
         cls, resource_name, cloudformation_json, region_name
@@ -630,7 +597,7 @@ class CloudFormationModel(BaseModel):
         pass
 
 
-class BaseBackend(object):
+class BaseBackend:
     def _reset_model_refs(self):
         # Remove all references to the models stored
         for service, models in model_data.items():
@@ -724,7 +691,7 @@ class BaseBackend(object):
     #     raise NotImplementedError()
 
 
-class ConfigQueryModel(object):
+class ConfigQueryModel:
     def __init__(self, backends):
         """Inits based on the resource type's backends (1 for each region if applicable)"""
         self.backends = backends
@@ -817,7 +784,7 @@ class ConfigQueryModel(object):
         raise NotImplementedError()
 
 
-class base_decorator(object):
+class base_decorator:
     mock_backend = MockAWS
 
     def __init__(self, backends):
