@@ -481,6 +481,14 @@ class CidrLimitExceeded(EC2ClientError):
         )
 
 
+class UnsupportedTenancy(EC2ClientError):
+    def __init__(self, tenancy):
+        super(UnsupportedTenancy, self).__init__(
+            "UnsupportedTenancy",
+            "The tenancy value {0} is not supported.".format(tenancy),
+        )
+
+
 class OperationNotPermitted(EC2ClientError):
     def __init__(self, association_id):
         super(OperationNotPermitted, self).__init__(
