@@ -34,6 +34,9 @@ from .vpc_peering_connections import VPCPeeringConnections
 from .vpn_connections import VPNConnections
 from .windows import Windows
 from .nat_gateways import NatGateways
+from .transit_gateways import TransitGateways
+from .transit_gateway_route_tables import TransitGatewayRouteTable
+from .transit_gateway_attachments import TransitGatewayAttachment
 from .iam_instance_profiles import IamInstanceProfiles
 
 
@@ -72,6 +75,9 @@ class EC2Response(
     VPNConnections,
     Windows,
     NatGateways,
+    TransitGateways,
+    TransitGatewayRouteTable,
+    TransitGatewayAttachment,
     IamInstanceProfiles,
 ):
     @property
