@@ -8,13 +8,27 @@ class TransitGateways(BaseResponse):
         description = self._get_param("Description") or None
         options = self._get_multi_param_dict("Options")
         tags = self._get_multi_param("TagSpecification")
-        tags = tags[0] if isinstance(tags, list) and len(tags) == 1 else tags
-        tags = (tags or {}).get("Tag", [])
-        tags = {t["Key"]: t["Value"] for t in tags}
+        if tags:
+            tags = tags[0].get("Tag")
 
         transit_gateway = self.ec2_backend.create_transit_gateway(
             description=description, options=options, tags=tags
         )
+
+        # creating default route table
+        transit_gateway_route_table = self.ec2_backend.create_transit_gateway_route_table(
+            transit_gateway_id=transit_gateway.id,
+            tags={},
+            default_association_route_table=True,
+            default_propagation_route_table=True,
+        )
+        transit_gateway.options[
+            "AssociationDefaultRouteTableId"
+        ] = transit_gateway_route_table.id
+        transit_gateway.options[
+            "PropagationDefaultRouteTableId"
+        ] = transit_gateway_route_table.id
+
         template = self.response_template(CREATE_TRANSIT_GATEWAY_RESPONSE)
         return template.render(transit_gateway=transit_gateway)
 
